@@ -29,13 +29,14 @@ exe('keymapviz ./qmk_firmware/keyboards/lets_split/keymaps/default/keymap.c -o l
 exe('keymapviz ./qmk_firmware/keyboards/lets_split/keymaps/default/keymap.c -o lets_split_{}.json -t json')
 exe('keymapviz ./qmk_firmware/keyboards/mint60/keymaps/default/keymap.c -o mint60.c')
 exe('keymapviz ./qmk_firmware/keyboards/mint60/keymaps/default/keymap.c -o mint60_{}.json -t json')
-exe('keymapviz ./qmk_firmware/keyboards/kyria/keymaps/default/keymap.c -o kyria.c')
-exe('keymapviz ./qmk_firmware/keyboards/kyria/keymaps/default/keymap.c -o kyria_{}.json -t json')
+exe('keymapviz ./qmk_firmware/keyboards/splitkb/kyria/keymaps/default/keymap.c -o kyria.c')
+exe('keymapviz ./qmk_firmware/keyboards/splitkb/kyria/keymaps/default/keymap.c -o kyria_{}.json -t json')
 exe('keymapviz ./qmk_firmware/keyboards/lily58/keymaps/default/keymap.c -o lily58.c')
 exe('keymapviz ./qmk_firmware/keyboards/lily58/keymaps/default/keymap.c -o lily58_{}.json -t json')
 exe('keymapviz ./qmk_firmware/keyboards/1upkeyboards/sweet16/keymaps/default/keymap.c -o sweet16.c')
 exe('keymapviz ./qmk_firmware/keyboards/1upkeyboards/sweet16/keymaps/default/keymap.c -o sweet16_{}.json -t json')
 exe('keymapviz -k dactyl_manuform5x6 ./qmk_firmware/keyboards/handwired/dactyl_manuform/5x6/keymaps/default/keymap.c -o dactyl_manuform5x6.c')
+exe('keymapviz -k dactyl_manuform5x6 ./qmk_firmware/keyboards/handwired/dactyl_manuform/5x6/keymaps/default/keymap.c -o dactyl_manuform5x6_fancy.c -t fancy')
 exe('keymapviz -k dactyl_manuform5x6 ./qmk_firmware/keyboards/handwired/dactyl_manuform/5x6/keymaps/default/keymap.c -o dactyl_manuform5x6_{}.json -t json')
 
 exe('keymapviz -r -k lets_split ./input/replace_lets_split_keymap.c >/dev/null 2>&1')
@@ -105,6 +106,9 @@ exe('diff -u expect/kyria_0.json kyria_0.json')
 exe('diff -u expect/kyria_1.json kyria_1.json')
 exe('diff -u expect/kyria_2.json kyria_2.json')
 exe('diff -u expect/kyria_3.json kyria_3.json')
+exe('diff -u expect/kyria_4.json kyria_4.json')
+exe('diff -u expect/kyria_5.json kyria_5.json')
+exe('diff -u expect/kyria_6.json kyria_6.json')
 
 exe('diff -u expect/lily58.c      lily58.c')
 exe('diff -u expect/lily58_0.json lily58_0.json')
@@ -115,8 +119,9 @@ exe('diff -u expect/lily58_3.json lily58_3.json')
 exe('diff -u expect/sweet16.c      sweet16.c')
 exe('diff -u expect/sweet16_0.json sweet16_0.json')
 
-exe('diff -u expect/dactyl_manuform5x6.c      dactyl_manuform5x6.c')
-exe('diff -u expect/dactyl_manuform5x6_0.json dactyl_manuform5x6_0.json')
+exe('diff -u expect/dactyl_manuform5x6.c       dactyl_manuform5x6.c')
+exe('diff -u expect/dactyl_manuform5x6_fancy.c dactyl_manuform5x6_fancy.c')
+exe('diff -u expect/dactyl_manuform5x6_0.json  dactyl_manuform5x6_0.json')
 
 exe('diff -u expect/replace_lets_split_keymap.c input/replace_lets_split_keymap.c')
 exe('diff -u expect/custom_legends_lets_split.c custom_legends_lets_split.c')
